package com.caimei.modules.club.controller;

import com.caimei.modules.club.entity.*;
import com.caimei.modules.club.service.CmUserOrganizeService;
import com.caimei.modules.club.service.CmUserService;
import com.caimei.modules.club.service.NewCmClubService;
import com.caimei.utils.*;
import com.github.pagehelper.PageHelper;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

/**
 * 会所管理
 */
@Controller
@RequestMapping(value = "/user/cmUserOrganize")
public class CmUserOrganizeController {
    @Autowired
    private CmUserOrganizeService cmUserOrganizeService;
    @Autowired
    private CmUserService cmUserService;
    @Autowired
    private NewCmClubService newCmClubService;

    /**
     * 会所列表
     */
    @ResponseBody
    @RequestMapping(value = "/clubList")
    public JsonModel toCmOrganizeClubList(CmUser cmUser, Page page) {
        PageHelper.startPage(page.getIndex(), page.getPageSize());
        List<CmUser> cmUserList = cmUserService.findListBuyUserInfo(cmUser);
        Page<CmUser> cmUserPage = new Page<>(cmUserList);
        return JsonModel.newInstance().success(cmUserPage);
    }

    /**
     * 上线会所(添加，编辑)
     *
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "/toAddClubUser")
    public JsonModel toAddClubUser(NewCmClub newCmClub) {
        if (null != newCmClub.getClubID()) {
            newCmClub = newCmClubService.findClubById(newCmClub.getClubID());
        }
        Integer provinceID = newCmClub.getProvinceID();
        Integer townID = newCmClub.getTownID();
        Integer cityID = newCmClub.getCityID();
        //控制编辑异常时候的会显地址下拉框
        if (null != provinceID && provinceID > 0) {
            Province province = cmUserOrganizeService.loadProvinceById(provinceID);
            newCmClub.setProvince(province.getName());
        }
        if (null != cityID && cityID > 0) {
            City city = cmUserOrganizeService.loadCityById(cityID);
            newCmClub.setCity(city.getName());
        }
        if (null != townID && townID > 0) {
            Town town = cmUserOrganizeService.loadTownByID(townID);
            newCmClub.setTown(town.getName());
        }
        return JsonModel.newInstance().success(newCmClub);
    }

    /**
     * 保存上线会所信息(添加，编辑)
     *
     * @param cmUserOrganize
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "saveAddClubUser")
    public JsonModel saveAddClubUser(CmUserOrganize cmUserOrganize, NewCmClub newCmClub, CmUser cmUser) throws Exception {
        JsonModel jsonModel = JsonModel.newInstance();
        String contractMobile = newCmClub.getContractMobile();
        Integer userID = newCmClub.getUserID();
        Integer clubID = newCmClub.getClubID();
        cmUser.setUserOrganizeID(cmUserOrganize.getId());
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String currentDate = sdf.format(new Date());
        //判断该会所手机号是否已存在
        cmUser.setBindMobile(contractMobile);
        List<CmUser> listBuyBindMobile = cmUserService.findListBuyBindMobile(cmUser);
        if (CollectionUtils.isNotEmpty(listBuyBindMobile) && listBuyBindMobile.size() > 0) {
            return jsonModel.error("该手机号码已被使用");
        }
        //添加用户信息（新增或修改通用）
        cmUser.setName(newCmClub.getName());
        cmUser.setUserName(newCmClub.getName());
        cmUser.setRealName(newCmClub.getName());
        cmUser.setClubStatus(String.valueOf(newCmClub.getStatus()));
        //添加用户新增信息
        if (null == userID) {//新增
            cmUser = initUser(cmUser, newCmClub);
            cmUserService.insert(cmUser);//插入新的用户数据
        }

        //修改图片全路径
        /*ImageUploadInfo saveImageSerivce = new ImageUploadInfo();
        String photoServer = Global.getConfig("photoServer");
        String businessLicenseImage = newCmClub.getBusinessLicenseImage();
        String headpic = newCmClub.getHeadpic();
        if (StringUtils.isNotBlank(businessLicenseImage) && !businessLicenseImage.startsWith("http:") && !businessLicenseImage.startsWith("https:")) {
            businessLicenseImage = Encodes.urlDecode(businessLicenseImage);
            String realPath = UploadImageUtils.getAbsolutePath(businessLicenseImage);
            int pointerIndex = realPath.lastIndexOf(".");
            try {
                saveImageSerivce = UploadUtils.saveImageSerivce(realPath, pointerIndex, realPath);
                newCmClub.setBusinessLicenseImage(photoServer + saveImageSerivce.getSource());
            } catch (Exception e) {
                logger.error("图片上传错误:" + e.toString(), e);
            }
        }
        if (StringUtils.isNotBlank(headpic) && !headpic.startsWith("http:") && !headpic.startsWith("https:")) {
            headpic = Encodes.urlDecode(headpic);
            String realPath = UploadImageUtils.getAbsolutePath(headpic);
            int pointerIndex = realPath.lastIndexOf(".");
            try {
                saveImageSerivce = UploadUtils.saveImageSerivce(realPath, pointerIndex, realPath);
                newCmClub.setHeadpic(photoServer + saveImageSerivce.getSource());
            } catch (Exception e) {
                logger.error("图片上传错误:" + e.toString(), e);
            }
        }*/
        //添加会所表信息
        newCmClub.setSname(newCmClub.getName());
        if (null == clubID) {
            newCmClub.setUserID(cmUser.getUserID());
            newCmClub.setDefaultServiceProviderID(AppKeys.DEFAULT_SPID);
            newCmClub.setSpID(AppKeys.DEFAULT_SPID);
            newCmClub.setMainServiceProviderID(AppKeys.DEFAULT_SPID);
            newCmClub.setScanFlag("2");
            newCmClub.setFlag("0");
            newCmClub.setAddTime(currentDate);
            newCmClub.setLinkMan1(newCmClub.getLinkMan());
            newCmClub.setContractMobile1(newCmClub.getContractMobile());
            newCmClub.setPayFlag1(AppKeys.FLAG_NO);
            newCmClub.setLevel(0d);
            newCmClub.setSubClubCount(0);
            newCmClub.setFavoriteTimes(0);
            newCmClub.setClubTypeID(1);
            newCmClub.setDefaultServiceProviderUpdTime(DateTimeUtil.getCurrentDateTime());
            newCmClubService.insert(newCmClub);

            //更新用户绑定关系
            cmUser.setClubID(String.valueOf(newCmClub.getClubID()));
            String nick = cmUser.getUserID() + "_" + RandomCodeGenerator.generateCodeString(4).toLowerCase();
            cmUser.setNick(nick);
            cmUser.setCompanyUserID(cmUser.getUserID());

            //更新会所绑定关系
            newCmClub.setUserID(cmUser.getUserID());
        }
        cmUserService.update(cmUser);//更新用户表数据(编辑数据，或新增数据更新)
        newCmClubService.update(newCmClub);//更新会所表数据(编辑数据，或新增数据更新)
        return jsonModel.success("保存成功");
    }


    /**
     * 初始化用户数据
     */
    public CmUser initUser(CmUser cmUser, NewCmClub newCmClub) {
        String curTime = DateUtils.getDateTime();
        cmUser.setRegisterUserTypeID("3");//设置为会所
        cmUser.setUserIdentity(2);
        cmUser.setServiceProviderStatus("90");//设置默认协销状态
        cmUser.setServiceProviderID("1342");
        cmUser.setAuditTime(curTime);
        cmUser.setAuditStatus("1");//审核通过
        cmUser.setAuditNote("后台添加用户系统默认审核通过");
        cmUser.setRegisterTime(curTime);
        cmUser.setLoginTime(curTime);
        cmUser.setAccount(newCmClub.getContractMobile() + RandomCodeGenerator.generateAccount(2));
        cmUser.setPassword(MD5Util.md5("caimei123"));
        cmUser.setBindMobile(newCmClub.getContractMobile());
        cmUser.setUserName(newCmClub.getName());
        cmUser.setEmailCheckFlag("0");
        cmUser.setMobileCheckFlag("0");
        cmUser.setUserMoney(0d);
        cmUser.setAbleUserMoney(0d);
        cmUser.setPoint("0");
        cmUser.setShopERPFlag("0");
        cmUser.setUserBeans("0");
        cmUser.setValidFlag("1");
        cmUser.setAgreeFlag("1");
        cmUser.setLoginFailTime("0");
        cmUser.setUserLevelID("1");
        cmUser.setScanFlag("2");
        cmUser.setUserPermission(2);
        return cmUser;
    }

    /**
     * 上下线会所
     *
     * @param cmUser
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "switchLine")
    public JsonModel switchLine(CmUser cmUser) {
        if (cmUser.getClubStatus().equals("91")) {
            cmUser.setClubStatus("90");
        } else {
            cmUser.setClubStatus("91");
        }
        cmUserService.update(cmUser);//更新用户表数据
        NewCmClub newCmClub = new NewCmClub();
        newCmClub.setClubID(Integer.parseInt(cmUser.getClubID()));
        newCmClub.setUserID(cmUser.getUserID());
        newCmClub.setStatus(90);
        newCmClubService.update(newCmClub);//更新会所表数据
        return JsonModel.newInstance().success();
    }

    /**
     * 省
     */
    @ResponseBody
    @RequestMapping("/province")
    public JsonModel getProvince() {
        List<Province> provinceList = cmUserOrganizeService.getProvince();
        return JsonModel.newInstance().success(provinceList);
    }

    /**
     * 市
     */
    @ResponseBody
    @RequestMapping("/city")
    public JsonModel getCity(Long provinceid) {
        List<City> cityList = cmUserOrganizeService.getCity(provinceid);
        return JsonModel.newInstance().success(cityList);
    }

    /**
     * 区
     */
    @ResponseBody
    @RequestMapping("/town")
    public JsonModel getTown(Integer cityid) {
        List<Town> townList = cmUserOrganizeService.getTown(cityid);
        return JsonModel.newInstance().success(townList);
    }

}