package com.caimei.modules.order.controller;

import com.caimei.modules.club.entity.Page;
import com.caimei.modules.order.entity.*;
import com.caimei.modules.order.service.*;
import com.caimei.utils.JsonModel;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 组织订单
 */
@Controller
@RequestMapping(value = "/order/organize")
public class OrganizeOrderController {
    @Autowired
    private NewOrderService newOrderService;
    @Autowired
    private BpClauseService bpClauseService;
    @Autowired
    private CmReturnedPurchaseService cmReturnedPurchaseService;
    @Autowired
    private CmReceiptOrderRelationService cmReceiptOrderRelationService;
    @Autowired
    private NewOrderConfigService newOrderConfigService;
    @Autowired
    private CmDiscernReceiptService cmDiscernReceiptService;
    @Autowired
    private NewShopOrderService newShopOrderService;

    @ModelAttribute
    public NewOrder getOrder(@RequestParam(required = false) String id) {
        NewOrder entity = null;
        if (StringUtils.isNotBlank(id)) {
            entity = newOrderService.get(id);
        }
        if (entity == null) {
            entity = new NewOrder();
        }
        return entity;
    }

    /**
     * 订单列表
     */
    @ResponseBody
    @RequestMapping("orderList")
    public JsonModel orderList(NewOrder order, Page page) {
        if (null != order.getStartTime() && !"".equals(order.getStartTime()) && !order.getStartTime().endsWith("00:00:00")) {
            order.setStartTime(order.getStartTime() + " 00:00:00");
        }
        if (null != order.getEndTime() && !"".equals(order.getEndTime()) && !order.getEndTime().endsWith("23:59:59")) {
            order.setEndTime(order.getEndTime() + " 23:59:59");
        }
        if (null != order.getStartRefundTime() && !"".equals(order.getStartRefundTime()) && !order.getStartRefundTime().endsWith("00:00:00")) {
            order.setStartRefundTime(order.getStartRefundTime() + " 00:00:00");
        }
        if (null != order.getEndRefundTime() && !"".equals(order.getEndRefundTime()) && !order.getEndRefundTime().endsWith("23:59:59")) {
            order.setEndRefundTime(order.getEndRefundTime() + " 23:59:59");
        }
        if (null != order.getBuyer()) {
            order.setBuyer(order.getBuyer().trim());
        }
        if (null != order.getReceiver()) {
            order.setReceiver(order.getReceiver().trim());
        }
        //查询内部处理了已收,未付统计（包含运费）
        Page<NewOrder> orderPage = newOrderService.findList(order, page);
        return JsonModel.newInstance().success(orderPage);
    }

    /**
     * 订单详情
     */
    @ResponseBody
    @RequestMapping("detail")
    public JsonModel detail(NewOrder order) {
        Map<String, Object> map = new HashMap();
        BpClause bpClause = new BpClause();
        bpClause.setEnabledStatus("1");
        List<BpClause> bpClauses = bpClauseService.findList(bpClause);
        map.put("bpClauses", bpClauses);
        //获取订单是否可以申请付款
        List<Integer> oId = new ArrayList<>();
        oId.add(order.getOrderID());
        List<Integer> orderIdsInApplyReturn = cmReturnedPurchaseService.findOrderIDsInApplyReturnFlag(oId);
        if (CollectionUtils.isNotEmpty(orderIdsInApplyReturn) && orderIdsInApplyReturn.size() > 0) {
            order.setApplyReturnedPurchaseFlag("0");
        } else {
            order.setApplyReturnedPurchaseFlag("1");
        }
        //判断是否有在收款审核的订单
        List<Integer> ids = cmReceiptOrderRelationService.toAudit(order.getOrderID());
        if (ids != null && ids.size() > 0) {
            order.setToAudit("1");
        }
        //一个子订单只有一个商品时,不可拆分
        int count = 0;
        for (NewShopOrder newShopOrder : order.getNewShopOrders()) {
            if (newShopOrder.getShopID() != 998) {
                count++;
            }
        }
        if (order.getProductCount() == null) {
            order.setProductCount(1);
        }
        if (order.getProductCount() <= count) {
            order.setSplitFlag("0");
        }
        map.put("order", order);
        if ("0".equals(order.getStatus())) {
            try {
                NewOrderConfig confirmOverTime = newOrderConfigService.getValueByKey("confirmOverTime");
                Double value = confirmOverTime.getValue(); //待确认超过 value 小时自动取消订单
                GregorianCalendar gc = new GregorianCalendar();
                SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
                Date orderTime = sdf.parse(order.getOrderTime());
                gc.setTime(orderTime);
                gc.add(Calendar.HOUR, value.intValue());
                Date time = gc.getTime();
                String ot = sdf.format(time);
                if (time.after(new Date())) map.put("time", ot);
            } catch (Exception e) {
                e.printStackTrace();
            }
        }
        CmReturnedPurchase cmReturnedPurchase = new CmReturnedPurchase();
        cmReturnedPurchase.setStatus("2");
        cmReturnedPurchase.setOrderID(order.getOrderID());
        List<CmReturnedPurchase> dataList = cmReturnedPurchaseService.getReturnedPurchaseList(cmReturnedPurchase);
        Double returnedPurchaseFee = 0D;    //退款(退货)总金额
        Double refundFee = 0D;  //退款总额(给买家)
        for (CmReturnedPurchase bean : dataList) {
            if (!bean.getStatus().equals("3")) {
                returnedPurchaseFee += bean.getReturnedPurchaseFee();
                refundFee += bean.getRefundFee();
            }
        }
        Double returnValue = 0d;   //退货价值
        if (order.getDiscountFee() >= returnedPurchaseFee) {
            returnValue = 0d;   //如果经理折扣大于退款(退货)总金额之和  那么先抵扣经理折扣  退款价值为0
        } else {
            returnValue = returnedPurchaseFee - order.getDiscountFee(); //抵用完经理折扣后才是真实价值
        }
        //订单已收金额
        Double receiptAmount = cmDiscernReceiptService.findOrderReceipt(order.getOrderID());
        map.put("returnValue", returnValue);
        map.put("receiptAmount", receiptAmount == null ? 0 : receiptAmount);
        map.put("returnedPurchaseFee", returnedPurchaseFee);
        return JsonModel.newInstance().success(map);
    }

    /**
     * 发货记录
     */
    @ResponseBody
    @RequestMapping("logisticsDetails")
    public JsonModel logisticsDetails(Integer orderID, String logisticsBatchID) {
        List<LogisticsInfoVo> logisticsInfoVos = new ArrayList<>();
        logisticsInfoVos = newShopOrderService.logisticsDetails(orderID, logisticsBatchID);
        return JsonModel.newInstance().success(logisticsInfoVos);
    }

    /**
     * 收退款记录
     */
    @ResponseBody
    @RequestMapping(value = "toRefundRecord")
    public JsonModel toRefundRecord(CmReturnedPurchase cmReturnedPurchase, String from) {
        JsonModel jsonModel = JsonModel.newInstance();
        Map<String, Object> map = new HashMap();
        try {
            NewOrder newOrder = newOrderService.get(cmReturnedPurchase.getOrderID().toString());
            List<CmReceiptOrderRelation> listRelation = cmReceiptOrderRelationService.findByOrderID(newOrder.getOrderID());
            List<CmReturnedPurchase> dataList = cmReturnedPurchaseService.getReturnedPurchaseList(cmReturnedPurchase);
            Double refundFee = 0D;  //退款总额
            for (CmReturnedPurchase bean : dataList) {
                if (!bean.getStatus().equals("3")) {
                    refundFee += bean.getRefundFee();
                }
            }
            map.put("cmReturnedPurchaseList", dataList);
            map.put("order", newOrder);
            map.put("receipt", listRelation);
            map.put("refundFee", refundFee);
            map.put("from", from);
            map.put("orderID", cmReturnedPurchase.getOrderID().toString());
        } catch (Exception e) {
            e.printStackTrace();
        }
        return jsonModel.success(map);
    }

    /**
     * 退款退货记录
     */
    @ResponseBody
    @RequestMapping(value = "toRecturnRecordByOrderID")
    public JsonModel toRecturnRecordByOrderID(CmReturnedPurchase cmReturnedPurchase) {
        Map<String, Object> map = new HashMap();
        try {
            NewOrder newOrder = newOrderService.get(cmReturnedPurchase.getOrderID().toString());
            List<CmReturnedPurchase> dataList = cmReturnedPurchaseService.getReturnedPurchaseList(cmReturnedPurchase);
            Double returnedPurchaseFee = 0D;    //退款(退货)总金额
            Double refundFee = 0D;  //退款总额(给买家)
            for (CmReturnedPurchase bean : dataList) {
                if (!bean.getStatus().equals("3")) {
                    returnedPurchaseFee += bean.getReturnedPurchaseFee();
                    refundFee += bean.getRefundFee();
                }
            }
            BpClause bpClause = new BpClause();
            bpClause.setEnabledStatus("1");
            List<BpClause> bpClauses = bpClauseService.findList(bpClause);
            map.put("bpClauses", bpClauses);
            map.put("cmReturnedPurchaseList", dataList);
            map.put("order", newOrder);
            map.put("returnedPurchaseFee", returnedPurchaseFee);
            map.put("refundFee", refundFee);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return JsonModel.newInstance().success(map);
    }
}
