package com.caimei.modules.order.service.impl;

import com.caimei.modules.order.dao.CmReturnedPurchaseDao;
import com.caimei.modules.order.dao.CmReturnedPurchaseProductDao;
import com.caimei.modules.order.dao.NewOrderProductDao;
import com.caimei.modules.order.entity.*;
import com.caimei.modules.order.service.CmReturnedPurchaseService;
import com.caimei.modules.order.service.NewShopOrderService;
import com.caimei.utils.AppUtils;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.*;

@Service
public class CmReturnedPurchaseServiceImpl implements CmReturnedPurchaseService {
    @Autowired
    private CmReturnedPurchaseDao cmReturnedPurchaseDao;
    @Autowired
    private CmReturnedPurchaseProductDao cmReturnedPurchaseProductDao;
    @Autowired
    private NewOrderProductDao newOrderProductDao;
    @Autowired
    private NewShopOrderService newShopOrderService;
    @Value("${malladmin.domain}")
    private String domain;

    @Override
    public List<Integer> findOrderIDsInApplyReturnFlag(List<Integer> oId) {
        return cmReturnedPurchaseDao.findOrderIDsInApplyReturnFlag(oId);
    }

    @Override
    public List<CmReturnedPurchase> getReturnedPurchaseList(CmReturnedPurchase cmReturnedPurchase) {
        List<CmReturnedPurchase> dataList = new ArrayList<CmReturnedPurchase>();
        dataList = cmReturnedPurchaseDao.findList(cmReturnedPurchase);
        if (null != dataList && dataList.size() > 0) {
            for (CmReturnedPurchase bean : dataList) {
                CmReturnedPurchaseProduct cmReturnedPurchaseProduct = new CmReturnedPurchaseProduct();
                cmReturnedPurchaseProduct.setReturnedID(bean.getId());
                List<CmReturnedPurchaseProduct> list = cmReturnedPurchaseProductDao.findList(cmReturnedPurchaseProduct);
                for (CmReturnedPurchaseProduct item : list) {
                    item.setMainImage(AppUtils.getImageURL("product", item.getMainImage(), 0, domain));//设置全路径
                    //计算商品的未出库和已取消和已发货数量
                    Integer notOutStore = 0;
                    Integer returnedPurchaseProductNum = 0;
                    Integer cancelProductNum = 0;
                    NewOrderProduct newOrderProduct = newOrderProductDao.get(item.getOrderProductID());
                    if (null != newOrderProduct) {
                        notOutStore = newOrderProduct.getNotOutStore();
                    }
                    //获取退货退款记录
                    CmReturnedPurchaseProduct purchaseProduct = new CmReturnedPurchaseProduct();
                    purchaseProduct.setShopOrderID(item.getShopOrderID());
                    purchaseProduct.setProductID(item.getProductID());
                    List<CmReturnedPurchaseProduct> cmReturnedPurchaseProductList = cmReturnedPurchaseProductDao.getCmReturnedPurchaseProductList(purchaseProduct);
                    if (CollectionUtils.isNotEmpty(cmReturnedPurchaseProductList)) {
                        for (CmReturnedPurchaseProduct c : cmReturnedPurchaseProductList) {
                            returnedPurchaseProductNum += c.getActualReturnedNum();
                            cancelProductNum += c.getActualCancelNum();
                        }
                    }
                    item.setNotOutStore(notOutStore);
                    item.setReturnedPurchaseProductNum(returnedPurchaseProductNum);
                    item.setCancelProductNum(cancelProductNum);


                    //判断订单商品是否是首次退货退款
                    Boolean isFirstReturn = false;
                    List<CmReturnedPurchaseProduct> temporaryList = cmReturnedPurchaseProductDao.findListByReturnTime(bean.getOrderID(), item.getShopOrderID(), item.getOrderProductID(), bean.getReturnTime());
                    if (null == temporaryList || temporaryList.size() == 0) {
                        isFirstReturn = true;
                    }
                    item.setFirstReturn(isFirstReturn);
                }

                //遍历List根据子订单分组
                Map map = new HashMap<String, List>();
                for (CmReturnedPurchaseProduct bean1 : list) {
                    if (map.containsKey(bean1.getShopOrderID())) {
                        List data = (List) map.get(bean1.getShopOrderID());
                        data.add(bean1);
                    } else {
                        List data = new ArrayList();
                        data.add(bean1);
                        map.put(bean1.getShopOrderID(), data);
                    }
                }
                //遍历map 把刚刚按照子订单排序的map取出来放到对象中
                List<ShopOrderReturned> shopOrderReturnedList = new ArrayList<ShopOrderReturned>();
                Iterator<Map.Entry<String, List<CmReturnedPurchaseProduct>>> entries = map.entrySet().iterator();
                while (entries.hasNext()) {
                    ShopOrderReturned shopOrderReturned = new ShopOrderReturned();
                    Map.Entry<String, List<CmReturnedPurchaseProduct>> entry = entries.next();
                    if (entry.getValue().size() > 0) {
                        shopOrderReturned.setCmReturnedPurchaseProductList(entry.getValue());
                        CmReturnedPurchaseProduct item = entry.getValue().get(0);
                        shopOrderReturned.setShopName(item.getShopName());
                        shopOrderReturned.setShopID(item.getShopID());
                        shopOrderReturned.setShopOrderID(item.getShopOrderID());
                        shopOrderReturned.setReturnedReceiver(item.getReturnedReceiver());
                        NewShopOrder shopOrder = newShopOrderService.findByShopOrderID(item.getShopOrderID());
                        if (null != shopOrder) {
                            shopOrderReturned.setProductAmount(shopOrder.getProductAmount());
                            shopOrderReturned.setPayStatus(shopOrder.getPayStatus());
                            shopOrderReturned.setSendOutStatus(shopOrder.getSendOutStatus());
                            shopOrderReturned.setShopOrderNo(shopOrder.getShopOrderNo());
                        }
                    }
                    shopOrderReturnedList.add(shopOrderReturned);
                }

                bean.setShopOrderReturnedList(shopOrderReturnedList);
            }
        }
        return dataList;
    }

    @Override
    public List<CmReturnedPurchase> findList(CmReturnedPurchase cmReturnedPurchase) {
        return cmReturnedPurchaseDao.findList(cmReturnedPurchase);
    }
}
