package com.caimei.modules.products.controller;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.caimei.modules.club.entity.Page;
import com.caimei.modules.products.entity.CmMallOrganizeProducts;
import com.caimei.modules.products.entity.CmMallPageModules;
import com.caimei.modules.products.entity.CmMallProductsClassify;
import com.caimei.modules.products.service.CmMallOrganizeProductsService;
import com.caimei.modules.products.service.CmMallProductsClassifyService;
import com.caimei.utils.JsonModel;
import com.github.pagehelper.PageHelper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;
import org.thymeleaf.util.StringUtils;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 小程序商城商品Controller
 *
 * @author lijun
 * @version 2019-12-04
 */
@Controller
@RequestMapping(value = "/product/cmMallOrganizeProducts")
public class CmMallOrganizeProductsController {

    @Autowired
    private CmMallOrganizeProductsService cmMallOrganizeProductsService;
    @Autowired
    private CmMallProductsClassifyService cmMallProductsClassifyService;

    /**
     * 去商品列表页面
     *
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "toProductList")
    public JsonModel toProductList(CmMallOrganizeProducts cmMallOrganizeProducts, Page page) {
        Map<String, Object> map = new HashMap();
        Page<CmMallOrganizeProducts> organizeProductsPage = cmMallOrganizeProductsService.findPage(page, cmMallOrganizeProducts);
        //商品分类下拉数据
        List<CmMallProductsClassify> listByEffective = cmMallProductsClassifyService.findListByEffective(cmMallOrganizeProducts.getOrganizeID());
        map.put("organizeProductsPage", organizeProductsPage);
        map.put("listByEffective", listByEffective);
        return JsonModel.newInstance().success(map);
    }

    /**
     * 商品模块列表
     */
    @ResponseBody
    @RequestMapping("/module")
    public JsonModel findAllModule(Integer organizeID) {
        List<CmMallPageModules> mallPageModulesList = cmMallOrganizeProductsService.findAllModule(organizeID);
        return JsonModel.newInstance().success(mallPageModulesList);
    }

    /**
     * 编辑回显
     */
    @ResponseBody
    @RequestMapping(value = "toEditProductInfo")
    public JsonModel toEditProductInfo(Integer id) {
        //获取商品分类列表
        Map<String, Object> map = new HashMap();
        CmMallOrganizeProducts organizeProducts = cmMallOrganizeProductsService.get(id);
        List<CmMallProductsClassify> listByEffective = cmMallProductsClassifyService.findListByEffective(organizeProducts.getOrganizeID());
        map.put("organizeProducts", organizeProducts);
        map.put("listByEffective", listByEffective);
        return JsonModel.newInstance().success(map);
    }

    /**
     * 编辑保存
     *
     * @param cmMallOrganizeProducts
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "saveEditProductInfo", method = RequestMethod.POST)
    public JsonModel saveEditProductInfo(@RequestBody CmMallOrganizeProducts cmMallOrganizeProducts) {
        JsonModel jsonModel = JsonModel.newInstance();
        try {
            cmMallOrganizeProducts.setUpdateTime(new Date());
            cmMallOrganizeProductsService.updateProductInfo(cmMallOrganizeProducts);
            return jsonModel.success("修改成功", "");
        } catch (Exception e) {
            return jsonModel.error("修改失败");
        }
    }

    /**
     * 上下架商品
     *
     * @param id 商品id
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "switchLine")
    public JsonModel switchLine(Integer id) {
        CmMallOrganizeProducts organizeProducts = cmMallOrganizeProductsService.get(id);
        if (organizeProducts.getValidFlag().equals("1")) {
            //下线商品
            organizeProducts.setPreferredProduct("0");
            organizeProducts.setCommonlyProduct("0");
            organizeProducts.setPreferentialProduct("0");
            organizeProducts.setValidFlag("2");
        } else {
            //上线商品
            organizeProducts.setValidFlag("1");
        }
        cmMallOrganizeProductsService.updateValidFlag(organizeProducts);
        return JsonModel.newInstance().success();
    }

    /**
     * 批量更新排序值
     *
     * @param newProducSorttList (商品id-排序值,...)
     * @return
     */
    @RequestMapping(value = "batchSaveSort")
    @ResponseBody
    public JsonModel batchSaveSort(String newProducSorttList, Integer modules) {
        JsonModel jsonModel = JsonModel.newInstance();
        try {
            String[] newPageLists = newProducSorttList.split(",");
            for (String list : newPageLists) {
                String[] split = list.split("-");
                if (split.length == 1 || split.length < 1) {
                    String id = split[0];
                    String sort = null;
                    cmMallOrganizeProductsService.saveSort(modules, sort, id);
                } else {
                    String id = split[0];
                    String sort = split[1];
                    if (CmMallProductsClassifyController.isInteger(sort)) {
                        if (StringUtils.equals("0", sort)) {
                            return jsonModel.error("排序值只能填写大于等于1的整数");
                        }
                        cmMallOrganizeProductsService.saveSort(modules, sort, id);
                    } else {
                        return jsonModel.error("排序值只能为数字");
                    }
                }
            }
            return jsonModel.success("更新排序成功", "");
        } catch (Exception e) {
            return jsonModel.error("更新排序失败");
        }
    }

    /**
     * 添加商品数据
     *
     * @param cmMallOrganizeProducts
     * @param page                   分页数据
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "toAddProduct1")
    public JsonModel toAddProduct1(CmMallOrganizeProducts cmMallOrganizeProducts, Page page) {
        //获取采美所有商品
        Map<String, Object> map = new HashMap();
        PageHelper.startPage(page.getIndex(), page.getPageSize());
        List<CmMallOrganizeProducts> listBuyMall = cmMallOrganizeProductsService.findListBuyMall(cmMallOrganizeProducts);
        Page<CmMallOrganizeProducts> productsPage = new Page<>(listBuyMall);
        //获取商品分类列表
        List<CmMallProductsClassify> listByEffective = cmMallProductsClassifyService.findListByEffective(cmMallOrganizeProducts.getOrganizeID());
        map.put("productsPage", productsPage);
        map.put("listByEffective", listByEffective);
        return JsonModel.newInstance().success(map);
    }

    /**
     * 添加商品
     *
     * @param cmMallOrganizeProducts
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "saveAddProductInfo")
    public JsonModel saveAddProductInfo(CmMallOrganizeProducts cmMallOrganizeProducts) {
        JsonModel jsonModel = JsonModel.newInstance();
        try {
            JSONArray parse = (JSONArray) JSON.parse(cmMallOrganizeProducts.getItemsList());
            if (null != parse && parse.size() > 0) {
                for (int j = 0; j < parse.size(); j++) {
                    String productID = (String) parse.get(j);//获取商品ID
                    CmMallOrganizeProducts cop = new CmMallOrganizeProducts();
                    cop.setId(Integer.valueOf(productID));
                    cmMallOrganizeProductsService.updateProductInfo1(cop);
                }
            }
            return jsonModel.success("添加成功", "");
        } catch (Exception e) {
            return jsonModel.error("添加失败");
        }
    }

    /**
     * //取消模块内商品
     *
     * @param cmMallOrganizeProducts
     * @return
     */
    @ResponseBody
    @RequestMapping(value = "canncelProduct", method = RequestMethod.POST)
    public JsonModel canncelProduct(@RequestBody CmMallOrganizeProducts cmMallOrganizeProducts) {
        cmMallOrganizeProducts.setUpdateTime(new Date());
        cmMallOrganizeProductsService.canncelPreferredProduct(cmMallOrganizeProducts);
        return JsonModel.newInstance().success();
    }
}