package com.caimei.modules.shiro.auth;

import com.caimei.modules.shiro.entity.CmMallAdminUser;
import com.caimei.modules.shiro.entity.Permission;
import com.caimei.modules.shiro.entity.Role;
import com.caimei.modules.shiro.service.ShiroService;
import com.caimei.utils.TokenEncryptUtils;
import com.github.pagehelper.util.StringUtil;
import org.apache.shiro.authc.*;
import org.apache.shiro.authz.AuthorizationInfo;
import org.apache.shiro.authz.SimpleAuthorizationInfo;
import org.apache.shiro.realm.AuthorizingRealm;
import org.apache.shiro.subject.PrincipalCollection;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

@Component
public class AuthRealm extends AuthorizingRealm {

    @Autowired
    private ShiroService shiroService;

    @Override
    /**
     * 授权(验证权限时候调用
     *@param  [principals]
     *@return org.apache.shiro.authz.AuthorizationInfo
     */
    protected AuthorizationInfo doGetAuthorizationInfo(PrincipalCollection principals) {
        //1. 从 PrincipalCollection 中来获取登录用户的信息
        CmMallAdminUser user = (CmMallAdminUser) principals.getPrimaryPrincipal();
        //Integer userId = user.getUserId();
        //2.添加角色和权限
        SimpleAuthorizationInfo simpleAuthorizationInfo = new SimpleAuthorizationInfo();
        for (Role role : user.getRoles()) {
            //2.1添加角色
            simpleAuthorizationInfo.addRole(role.getRoleName());
            for (Permission permission : role.getPermissions()) {
                //2.1.1添加权限
                simpleAuthorizationInfo.addStringPermission(permission.getPermission());
            }
        }
        return simpleAuthorizationInfo;
    }

    @Override
    /**
     * 认证(登陆时候调用)
     *@param  [token]
     *@return org.apache.shiro.authc.AuthenticationInfo
     */
    protected AuthenticationInfo doGetAuthenticationInfo(AuthenticationToken token) throws AuthenticationException {
        String accessToken = TokenEncryptUtils.decoded((String) token.getPrincipal());
        //2. token失效
        String[] tokens = accessToken.split("#,#");
        if (StringUtil.isEmpty(accessToken) || Integer.parseInt(tokens[0]) < (System.currentTimeMillis() / 1000)) {
            throw new IncorrectCredentialsException("token失效，请重新登录");
        }
        //3. 调用数据库的方法, 从数据库中查询 username 对应的用户记录
        CmMallAdminUser user = shiroService.findByUserId(Integer.valueOf(tokens[1]));
        //4. 若用户不存在, 则可以抛出 UnknownAccountException 异常
        if (user == null) {
            throw new UnknownAccountException("用户不存在!");
        }
        String infos = TokenEncryptUtils.encoded(tokens[0] + "#,#" + user.getId() + "#,#" + user.getPassword());
        //5. 根据用户的情况, 来构建 AuthenticationInfo 对象并返回. 通常使用的实现类为: SimpleAuthenticationInfo
        SimpleAuthenticationInfo info = new SimpleAuthenticationInfo(user, infos, this.getName());
        return info;
    }
}
