package com.caimei.modules.shiro.controller;


import com.caimei.modules.shiro.entity.CmMallAdminUser;
import com.caimei.modules.shiro.entity.CmMallOrganize;
import com.caimei.modules.shiro.service.ShiroService;
import com.caimei.utils.JsonModel;
import com.caimei.utils.MD5Util;
import com.caimei.utils.TokenEncryptUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Date;


@RestController
@RequestMapping("/user")
public class ShiroController {

    @Autowired
    private ShiroService shiroService;


    /**
     * 登录
     */
    @PostMapping("/login")
    public JsonModel login(@RequestBody CmMallAdminUser adminUser) {
        JsonModel jsonModel = JsonModel.newInstance();
        //用户信息
        CmMallAdminUser user = shiroService.findByUsername(adminUser.getAccount(), adminUser.getOrganizeID());
        //账号不存在、密码错误
        if (user == null || !user.getPassword().equals(MD5Util.md5(adminUser.getPassword() + user.getSalt()))) {
            return jsonModel.error("账号或密码有误");
        } else {
            //生成token
            String token = null;
            try {
                token = shiroService.createToken(user);
            } catch (Exception e) {
                return jsonModel.error("生成token失败");
            }
            return jsonModel.success(token);
        }
    }

    /**
     * 返回用户信息
     *
     * @param token
     * @return
     */
    @GetMapping("/info")
    public JsonModel info(String token) {
        String decoded = TokenEncryptUtils.decoded(token);
        String[] tokens = decoded.split("#,#");
        //用户信息
        CmMallAdminUser user = shiroService.findByUserId(Integer.valueOf(tokens[1]));
        return JsonModel.newInstance().success(user);
    }

    /**
     * 修改密码
     */
    @RequestMapping(value = "changePassword", method = RequestMethod.POST)
    public JsonModel changePassword(@RequestBody CmMallAdminUser adminUser, HttpServletRequest httpRequest) {
        JsonModel jsonModel = JsonModel.newInstance();
        if (adminUser.getPassword().equals(adminUser.getOldPassword())) return jsonModel.error("新密码不能与老密码一样");
        String token = httpRequest.getHeader("token");
        String decoded = TokenEncryptUtils.decoded(token);
        String[] tokens = decoded.split("#,#");
        CmMallAdminUser user = shiroService.findByUserId(Integer.valueOf(tokens[1]));
        String oldPassword = MD5Util.md5(adminUser.getOldPassword() + user.getSalt());
        if (user.getPassword().equals(oldPassword)) {
            String salt = MD5Util.salt();
            String password = MD5Util.md5(adminUser.getPassword() + salt);
            user.setPassword(password);
            user.setSalt(salt);
            user.setUpdateTime(new Date());
            shiroService.changePassword(user);
            return jsonModel.success();
        }
        return jsonModel.error("旧密码输入不正确,请重新输入");
    }

    /**
     * 组织信息数据
     */
    @RequestMapping("organizeInfo")
    public JsonModel organizeInfo(Integer id) {
        CmMallOrganize mallOrganize = shiroService.findOrganize(id);
        return JsonModel.newInstance().success(mallOrganize);
    }

    /**
     * 修改组织信息
     */
    @RequestMapping(value = "update", method = RequestMethod.POST)
    public JsonModel updateOrganizeInfo(@RequestBody CmMallOrganize mallOrganize) {
        shiroService.updateOrganizeInfo(mallOrganize);
        return JsonModel.newInstance().success();
    }
}


